@@ -2,20 +2,19 @@
 from plone import api
 from plone.namedfile.field import NamedBlobFile
 from rer.newsletter import _
-from rer.newsletter.utility.channel import IChannelUtility
-from rer.newsletter.utility.channel import OK
-from rer.newsletter.utility.channel import UNHANDLED
+from rer.newsletter.adapter.subscriptions import IChannelSubscriptions
+from rer.newsletter.utils import OK
+from rer.newsletter.utils import UNHANDLED
+from six import PY2
+from six.moves import range
 from z3c.form import button
 from z3c.form import field
 from z3c.form import form
 from zope import schema
-from zope.component import getUtility
+from zope.component import getMultiAdapter
 from zope.interface import Interface
-
 import csv
 import re
-from six.moves import range
-from six import PY2
 
 try:
     from StringIO import StringIO
@@ -103,7 +102,6 @@ class UsersImport(form.Form):
     def processCSV(self, data, headerline, separator):
         input_data = data.decode()
         input_separator = separator.encode('ascii', 'ignore').decode()
-
         if PY2:
             input_data = data
             input_separator = separator.encode('ascii', 'ignore')
@@ -111,12 +109,9 @@ class UsersImport(form.Form):
         io = StringIO(input_data)
 
         reader = csv.reader(
-            io,
-            delimiter=input_separator,
-            dialect='excel',
-            quotechar='\'',
+            io, delimiter=input_separator, dialect='excel', quotechar='\''
         )
-        index = 0
+        index = 1
         if headerline:
             header = next(reader)
 
@@ -160,38 +155,35 @@ class UsersImport(form.Form):
             self.status = self.formErrorsMessage
             return
 
-        # prendo la connessione con il server mailman
-        api_channel = getUtility(IChannelUtility)
+        channel = getMultiAdapter(
+            (self.context, self.request), IChannelSubscriptions
+        )
 
         # devo svuotare la lista di utenti del channel
         if data['emptyList']:
-            status = api_channel.emptyChannelUsersList(self.context.id_channel)
+            status = channel.emptyChannelUsersList()
 
         csv_file = data['userListFile'].data
         # esporto la lista di utenti dal file
         usersList = self.processCSV(
             csv_file, data['headerLine'], data['separator']
         )
-
         # controllo se devo eliminare l'intera lista di utenti
         # invece di importarla
         if data['removeSubscribers'] and not data['emptyList']:
             # chiamo l'api per rimuovere l'intera lista di utenti
             if usersList:
-                status = api_channel.deleteUserList(
-                    self.context.id_channel, usersList
-                )
+                status = channel.deleteUserList(usersList)
 
         else:
             if usersList:
                 # mi connetto con le api di mailman
-                status = api_channel.importUsersList(
-                    self.context.id_channel, usersList
-                )
+                status = channel.importUsersList(usersList)
 
         if status == OK:
             status = _(
-                u'generic_subscribe_message_success', default=u'User Subscribed'
+                u'generic_subscribe_message_success',
+                default=u'User Subscribed',
             )
             api.portal.show_message(
                 message=status, request=self.request, type=u'info'
